@@ -2,4 +2,8 @@ from .email import Emailer
 from .logs import Logger
 from .slack import Slacker
 
-__all__ = ("Emailer", "Logger", "Slacker", )
+__all__ = (
+    "Emailer",
+    "Logger",
+    "Slacker",
+)
